---
title: KG이니시스 일본결제 서비스 이용안내
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
tags:
  - 해외결제
  - KG이니시스
pgCompanies:
  - KG이니시스
searchTags:
  - 일본
  - KG이니시스 일본
  - 이니시스 해외결제
  - JPY
  - 글로벌 일본결제
  - 일본결제
  - 이니시스 일본결제
datetime: 2025-02-13T06:02:32.259Z
---

<Callout content="" title="KG이니시스를 통한 일본결제 이용시 아래 특징을 참고해주세요!" />

### **KG이니시스 일본결제 서비스 이용안내**

- 글로벌 서비스 확장 시, 현지 국가 결제 수단 기능 추가 연동 개발 없이 이용 가능
- 다양한 기능을 제공하는 관리자 콘솔 지원
- 링크 생성 결제 기능 지원
- 코리아포트원 설정 없이 글로벌 포트원 콘솔 설정/연동 가능

#### **서비스 이용절차**

- 포트원 해외결제서비스 [도입문의](https://go.portone.io/l/1047343/2023-11-27/6rv/?_gl=1*19xamm*_gcl_au*MTk3NzM1MTQzMC4xNzE3NzMwMDU0*_ga*OTE5ODY1NzY1LjE3MDY3Nzk5MDA.*_ga_PD0FDL16NZ*MTcxODE4MDYwMy4xNDEuMS4xNzE4MTgyOTkzLjAuMC4w) 신청
- KG이니시스 사전 심사 진행
- 포트원 서비스 이용 계약 진행
- KG이니시스 계약 진행 (가입신청/카드사 심사)

#### **지원 결제 수단**

- 해외 발행 글로벌 카드 : VISA, Master, JCB, AMEX, Diners Club
- 편의점결제 : 7Eleven, LAWSON, FamilyMart, MINISTOP, SEICO MART
- 간편결제 : RPay, AmazonPay, D barai, AU Pay,  MerPay

#### **지원 결제 방식**

- 해외카드 일반(인증) , 편의점결제, 간편결제 일반(인증) 결제창 방식

#### **지원 하는 통화**

- 결제통화

<Indent level="1">

- 해외카드 JPY

</Indent>

- 정산통화

<Indent level="1">

- 정산 가능 통화 : KRW

</Indent>

#### **결제 수수료(VAT별도) 및 정산주기**

<Indent level="1">

1. 실물

- 신용카드 : VISA/MASTER/JCB/AMEX/DINERS\
  정산주기 : 월 3회 또는 6회 \
  수수료 : 3.9% +0.5%(포트원 이용요금)
- 편의점결제 : 7Eleven/LAWSON/FamilyMart/MINISTOP/SEICO MART\
  정산주기 : 월 3회 \
  수수료 : 3.7% +0.5%(포트원 이용요금)
- 간편결제 : RPay/AmazonPay/D barai/AU Pay/ MerPay\
  정산주기 : 월3회 \
  수수료 : 6.7% +0.5% (포트원 이용요금)

2\. 비실물

- 신용카드 : VISA/MASTER/JCB/AMEX/DINERS\
  정산주기 : 월 3회 또는 6회 \
  수수료 : 6.5% +0.5%(포트원 이용요금)
- 편의점결제 : 7Eleven/LAWSON/FamilyMart/MINISTOP/SEICO MART\
  정산주기 : 월 3회 \
  수수료 : 3.7% +0.5%(포트원 이용요금)
- 간편결제 : RPay/AmazonPay/D barai/AU Pay/ MerPay\
  정산주기 : 월3회 \
  수수료 : 13.7% +0.5% (포트원 이용요금)

</Indent>

#### **편의점 결제 안내**

- 편의점 결제의 경우, 최저 수수료 : 180엔
- 편의점 결제의 경우, PG사에서 환불을 진행하고 있지 않아 고객사에서 직접 환불 진행 해야 하는 점 참고 부탁드립니다.

#### **이니시스 심사비 및 연관리비(VAT별도)**

<Indent level="1">

- 초기등록비(심사비) : 150,000원 (VAT별도)
- 연관리비 : 600,000원 (VAT별도)

</Indent>

#### **포트원 이용요금(VAT별도)**<Highlight />

<Indent level="1">

0.50% (minimum 500 USD)

- 코리아 포트원과 별도 계약이 필요 합니다.
- 전월 발생된 거래액 기준으로 청구 됩니다.

</Indent>

### **사전심사**

- KG이니시스JP의 경우, 사전심사가 필수이며, 사전 심사를 완료 후, 본 심사가 가능합니다
- \*\*\*\*<Highlight text="아래 사전 심사 항목을 반드시 cs@portone.io 메일로 보내주셔야 접수가 가능합니다. " />

**\[사전심사 항목]**

- 상호명 :
- 국내사업자번호 :
- 사이트명 :
- 월 거래액 (엔화 기준):
- 객단가 :
- 사이트 URL :
- 서비스 제공 및 배송기간 :
- 쇼피파이 호스팅 사용 여부 :

#### **웹사이트 필수 구축 요건**

\[PG사 심사를 위한 서비스 구축 요건]

- 첨부된 링크 참고해주시면 감사하겠습니다.
- 일본 결제 관련 사이트 필수 요건 안내
  - \[이용규약 관련]이용규약의 경우 국내법이 아닌 현지법 기준으로 기재 필요(한국 청소년보호법 등 기재 X)
    - 예시: <https://www.tixply.io/footer/clause/view> 의 第10条準拠法
  - \[특정상거래법 적용 필요]
    - 예시: <https://www.tixply.io/footer/specifiedCommercialTransaction/view>
    - 販売業者 \~ 電話番号 까지는 이니시스 재팬 정보 입력 필요 (나머지는 고객사 정보로 입력해두기)
      - 예시) 電話番号 : 03-3508-2070

#### 📌 결제대행사별 위험 업종유형을 참고 하세요!

- 결제대행사(PG) 계약을 위해서는 온라인 결제시 판매하는 서비스(상품) 유형을 1차적으로 심사를 하고 입점 가능여부가 결정됩니다.
- 결제대행사(PG)별 입점 심사 기준(RM)정책은 카드사 등록불가 업종 기준을 바탕으로 적용됩니다.

<Callout title="KG이니시스_일본결제 심사조건 보러가기 ↗" />

### **이니시스 일본결제** **연동방법**

- [글로벌 포트원 가입 ↗](https://admin.portone.cloud/register) > 가입 후 테스트 연동을 위한 \[[글로벌 포트원 콘솔 ↗](https://admin.portone.cloud/)] 채널(PSP)정보 설정 및 결제 테스트 진행
- [글로벌 포트원 결제 연동 메뉴얼 보러가기↗](https://www.docs.portone.cloud/docs/cross_border/cross_border_integration)
- [글로벌 포트원\_이니시스 테스트 연동정보 보러가기↗](https://www.docs.portone.cloud/docs/cross_border/cross_border_integration)
- [글로벌 포트원\_통합 콘솔 가이드 보러가기↗](https://docs-v2.portone.cloud/docs/getting-started-2)

<Callout title="참고사항" content="카드사/서비스 원천사 심사시 일본어 사이트와 일본 결제서비스 연동이 되어 있어야 심사가 가능한 부분 참고 부탁드립니다." icon="💡" />

### **글로벌 포트원 콘솔 설정 및 결제창 예시**

- 글로벌 포트원 콘솔 설정화면 예시





- 신용카드 결제창 예시



<Callout title="글로벌_해외결제 대행사별 위험업종 유형 보러가기 ↗" />
